from ase.io import read
from ase.optimize import BFGS
from gpaw import GPAW, PoissonSolver
from gpaw.xc.libvdwxc import vdw_df_cx
from gpaw.utilities import h2gpts

system = read('CHL_A_NMe4pl_PBE_d2SVP_geo.xyz')
system.center(vacuum=6.0)

calc = GPAW(mode='lcao',
            basis='dzp',
            charge=1.0,
            gpts=h2gpts(0.18, system.cell, idiv=16),
            poissonsolver=PoissonSolver(relax='GS'),
            xc=vdw_df_cx(),
            parallel=dict(sl_auto=True),
            txt='gpaw.txt')
system.calc = calc
system.get_forces()
calc.write('dump.initial.gpw', mode='all')

opt = BFGS(system, trajectory='opt.traj',
           logfile='opt.log')
opt.run(fmax=0.05)

calc.write('dump.relaxed.gpw', mode='all')
